@@ -95,16 +95,6 @@ dlog (int level, const char *str)
 }
 #endif
 
-extern gnutls_alloc_function gnutls_secure_malloc;
-extern gnutls_alloc_function gnutls_malloc;
-extern gnutls_free_function gnutls_free;
-extern int (*_gnutls_is_secure_memory) (const void *);
-extern gnutls_realloc_function gnutls_realloc;
-extern char *(*gnutls_strdup) (const char *);
-extern void *(*gnutls_calloc) (size_t, size_t);
-
-int _gnutls_is_secure_mem_null (const void *);
-
 /**
   * gnutls_global_set_mem_functions - set the memory allocation functions
   * @alloc_func: it's the default memory allocation function. Like malloc().
@@ -389,8 +379,6 @@ gnutls_transport_set_push_function (gnutls_session_t session,
   session->internals._gnutls_push_func = push_func;
 }
 
-#include <strverscmp.h>
-
 /**
   * gnutls_check_version - check the library's version
   * @req_version: the version to check
